@@ -9,15 +9,18 @@ const requiredPlugins: Record<string, [string, { isVisible: boolean; allowedActi
         { isVisible: true, allowedActions: { toggle: true } },
     ],
 };
-try {
-    await ipcRenderer.invoke("getShelterBundle").then(async (bundle: ModBundle) => {
-        if (bundle.enabled) {
-            await webFrame.executeJavaScript(`(()=>{
+async function inject() {
+    try {
+        await ipcRenderer.invoke("getShelterBundle").then(async (bundle: ModBundle) => {
+            if (bundle.enabled) {
+                await webFrame.executeJavaScript(`(()=>{
                 const SHELTER_INJECTOR_PLUGINS = ${JSON.stringify(requiredPlugins)};
                 ${bundle.js}
             })()`);
-        }
-    });
-} catch (e) {
-    console.error(e);
+            }
+        });
+    } catch (e) {
+        console.error(e);
+    }
 }
+inject();
